﻿// Copyright (c) Pixel Crushers. All rights reserved.

using UnityEngine;
using System;
using System.Collections.Generic;

namespace PixelCrushers.DialogueSystem
{

    /// <summary>
    /// Add this to the Dialogue Manager to allow it to dispatch quest state updates
    /// to QuestStateListener components on other GameObjects.
    /// </summary>
    [AddComponentMenu("")] // Added automatically by QuestStateListener.
    public class QuestStateDispatcher : MonoBehaviour
    {
        public interface IQuestStateListener
        {
            string GetQuestName();

            void OnChange();
        }

        private List<IQuestStateListener> m_listeners = new List<IQuestStateListener>();

        public void AddListener(IQuestStateListener listener)
        {
            if (listener == null) return;
            m_listeners.Add(listener);
        }

        public void RemoveListener(IQuestStateListener listener)
        {
            m_listeners.Remove(listener);
        }

        public void OnQuestStateChange(string questName)
        {
            for (int i = 0; i < m_listeners.Count; i++)
            {
                var listener = m_listeners[i];
                if (string.Equals(questName, listener.GetQuestName()))
                {
                    listener.OnChange();
                }
            }
        }

    }
}